#
# spec file for package mpibash
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mpibash
Version:        1.3
Release:        5.1
Summary:        Parallel scripting right from the Bourne-Again Shell
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Other
URL:            https://github.com/lanl/MPI-Bash
Source0:        https://github.com/lanl/MPI-Bash/releases/download/v%{version}/mpibash-%{version}.tar.gz
Patch0:         Replace-deprecated-MPI_Errhandler_set-with-newer-MPI_Comm_set_errhandler.patch
Patch1:         Cast-function-pointer-types-so-they-can-be-compared-without-warnings.patch
BuildRequires:  bash-devel >= 4.4
BuildRequires:  libcircle-devel
BuildRequires:  openmpi-macros-devel
%openmpi_requires
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
MPI-Bash makes it possible to parallelize Bash scripts which run a set of
Linux commands independently over a large number of input files.
Because MPI-Bash includes various MPI functions for data transfer and
synchronization, it is not limited to parallel workloads
but can incorporate phased operations (i.e. all workers must finish
operation X before any worker is allowed to begin operation Y).

%package examples
Summary:        Example Scripts for %{name}
Group:          Productivity/Scientific/Chemistry
Requires:       %{name} = %{version}

%description examples
MPI-Bash makes it possible to parallelize Bash scripts which run a set of
Linux commands independently over a large number of input files.

This package contains example scripts for mpibash.

%prep
%autosetup -p0

%build
%setup_openmpi
# This is to avoid an issue with execute_shell_function which is declared in
# /usr/include/bash/execute_cmd.h but it does not exists for "older" bash
# versions. Once updatig to v1.4 (which will require this header), this flag should
# be dropped
export CFLAGS="-Wno-implicit-function-declaration"
%configure --docdir=%{_docdir}/%{name} --with-plugindir=%{_libdir}/%{name}/ CC=mpicc
%make_build

%install
%make_install
# Fix shebang
sed -i '1s@/usr/bin/env bash@/bin/bash@' %{buildroot}/%{_bindir}/mpibash
sed -i '1s@env mpibash@mpibash@' %{buildroot}/%{_docdir}/%{name}/examples/* %{buildroot}/%{_bindir}/m*

%files
%defattr(-,root,root,-)
%{_bindir}/m*
%{_libdir}/%{name}/
%{_mandir}/man1/m*
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/examples

%files examples
%defattr(-,root,root,-)
%{_docdir}/%{name}/examples

%changelog
* Thu Sep  5 2024 Nicolas Morey <nicolas.morey@suse.com>
- Add Cast-function-pointer-types-so-they-can-be-compared-without-warnings.patch
  to fix compilation issues with GCC >= 14
- Add workaround a missing bash function definition
* Fri Feb 23 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue May  4 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Add Replace-deprecated-MPI_Errhandler_set-with-newer-MPI_Comm_set_errhandler.patch
  to fix compilation with openmpi4
* Mon May 27 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Always use the default openmpi
* Wed Nov 22 2017 junghans@votca.org
- Version bump to v1.3
  * drop 8.patch - got merge upstream
  * "This release includes a few bug fixes, a few improvements to
    the build process, and some extra information added to the
    documentation."
* Tue Nov 14 2017 jengelh@inai.de
- Ensure neutrality of description. Trim it subpackages.
* Fri Nov 10 2017 junghans@votca.org
- added 8.patch - circle_init_builtin: fix return value
* Fri Nov 10 2017 junghans@votca.org
- initial add of v1.2
